/***********************************************************/
/*                                                         */
/* Amiga C Encyclopedia (ACE)           Amiga C Club (ACC) */
/* --------------------------           ------------------ */
/*                                                         */
/* Manual:  AmigaDOS                    Amiga C Club       */
/* Chapter: Handlers                    Tulevagen 22       */
/* File:    Example1.c                  181 41  LIDINGO    */
/* Author:  Anders Bjerin               SWEDEN             */
/* Date:    93-03-16                                       */
/* Version: 1.1                                            */
/*                                                         */
/*   Copyright 1993, Anders Bjerin - Amiga C Club (ACC)    */
/*                                                         */
/* Registered members may use this program freely in their */
/*     own commercial/noncommercial programs/articles.     */
/*                                                         */
/***********************************************************/

/* This is an example on how to open a console window on the */
/* default screen (usually the Workbench Screen). The window */
/* will first be closed when the user clicks on the close    */
/* gadget or types CTRL-\.                                   */
/*                                                           */
/* These types of console windows can be very handy when you */
/* want to give the user some information. Console windows   */
/* are easy to use and look good.                            */
/*                                                           */
/* This program uses some flags which are only available in  */
/* dos library version 36 or higher. The program can however */
/* still run on the older systems. The console window will   */
/* then however be immediately closed when we close the      */
/* file.                                                     */



/* Include the dos library definitions: */
#include <dos/dos.h>

/* Now we include the necessary function prototype files:         */
#include <clib/dos_protos.h>       /* General dos functions...    */
#include <clib/exec_protos.h>      /* System functions...         */
#include <stdio.h>                 /* Std functions [printf()...] */
#include <stdlib.h>                /* Std functions [exit()...]   */
#include <string.h>                /* Std functions [strlen()...] */



/* There are 10 lines of text we want to print: */
#define NUMBER_LINES 10



/* Set name and version number: */
UBYTE *version = "$VER: AmigaDOS/Handlers/Example1 1.1";



/* Declared our own function(s): */

/* Our main function: */
int main( int argc, char *argv[] );



/* Main function: */

int main( int argc, char *argv[] )
{
  /* Some text we want to display: */
  UBYTE *my_text[ NUMBER_LINES ] =
  {
    "The Amiga C Encyclopedia\nCopyright 1989-1993\nAnders Bjerin\n\n",
    "An important message to all C programmers! The Amiga C Encyclopedia ",
    "is shareware. If you use this manual or any other part in the ",
    "Encyclopedia you MUST pay the registration fee! The fee is less ",
    "than what a simple game cost, and a game may last two or three ",
    "months at most while the Encyclopedia can give you years of fun ",
    "and help!\n\nTo all honourable programmers who have already ",
    "registered their copies I would like to send my best regards, ",
    "and may the bugs be few...\n\n\t\tHappy Programming, ",
    "\n\t\tAnders Bjerin\n\n(Only the Amiga makes it fun!)\n"
  };

  /* A "BCPL" pointer to our console window: */
  BPTR my_console;
  
  /* Store here the number of bytes actually written: */
  long bytes_written;

  /* A simple loop variable: */
  int loop; 


  /* We will now open a console window on the default   */
  /* (usually Workbench) screen. The window will have   */
  /* the title "My Console", and there will be a close  */
  /* gadget in the top left corner of the window. Since */
  /* we also have set the flag "/WAIT" the window will  */
  /* first be closed when the user clicks on the close  */
  /* gadget or types CTRL-\.                            */
  /*                                                    */
  /* Please note that these flags are only available    */
  /* in dos library V36 or higher. The program will     */
  /* however still be able to run on the old versions   */
  /* but there will not be any close gadget and the     */
  /* window will close immediately when we close the    */
  /* file.                                              */
  my_console = 
   Open( "CON:0/0/640/200/My Console/CLOSE/WAIT", MODE_NEWFILE );
  
  /* Have we opened the console successfully? */
  if( my_console == NULL )
  {
    /* Inform the user: */
    printf( "Error! Could not open the console window!\n" );

    /* Exit with an error code: */
    exit( 20 );
  }


  /* Write all lines: */
  for( loop = 0; loop < NUMBER_LINES; loop++ )
  {
    /* Write one line: */
    bytes_written =
      Write( my_console, my_text[ loop ], strlen( my_text[ loop ] ) );

    /* Could we write the complete line: */
    if( bytes_written != strlen( my_text[ loop ] ) )
    {
      /* No! We could not write the whole line! */
      printf( "Error! Could not write all text!\n" );

      /* Close the console window: */
      Close( my_console );

      /* Exit with an error code: */
      exit( 21 );
    }
  }



  /* Close the console window: */
  Close( my_console );

  /* Note! Since we have opened a console window with a close */
  /* gadget and set the flag "WAIT" the console window will   */
  /* actually first be closed when the user clicks on the     */
  /* close gadget or types "CTRL-\".                          */

  /* If the user has an old version of the dos library (before V36), */
  /* the special flags will not work. The window will therefore      */
  /* immediately be closed when you close the window, and there is   */
  /* not any close gadget at the top left corner of the window.      */
  /* Since the window will immediately be closed when we close the   */
  /* file, it will be difficult for the user to read any message     */
  /* before the window is closed. You should in such case try to     */
  /* read some values from the console and ask the user to press     */
  /* enter when he/she wants to close with window. The Read()        */
  /* function will only return when the user has pressed enter, and  */
  /* it can therefore be used to halt the execution. See next        */
  /* example for more information on how to collect values from a    */
  /* console window.                                                 */



  /* The End! */
  exit( 0 );
}
               
